@@ -46,6 +46,7 @@
 
 #if HAVE_MB_EXTRACT_UUID
 #define GET_ID(field, function, obj) {						\
+	char uuid_buffer[37];							\
         function (obj, buffer, sizeof (buffer));				\
 	mb_extract_uuid (buffer, uuid_buffer, sizeof (uuid_buffer));		\
 	if (field)								\
@@ -63,6 +64,7 @@
 }
 #endif /* HAVE_MB_EXTRACT_UUID */
 
+#define GCONF_MUSICBRAINZ_SERVER "/apps/sound-juicer/musicbrainz_server"
 #define GCONF_PROXY_USE_PROXY "/system/http_proxy/use_http_proxy"
 #define GCONF_PROXY_HOST "/system/http_proxy/host"
 #define GCONF_PROXY_PORT "/system/http_proxy/port"
@@ -108,7 +110,6 @@ make_album_from_release (MbRelease *release)
 {
   AlbumDetails *album;
   char buffer[512];
-  char uuid_buffer[37];
   MbArtist artist;
   char *new_title;
   int i;
@@ -314,14 +315,24 @@ static void
 sj_metadata_musicbrainz3_init (SjMetadataMusicbrainz3 *self)
 {
   GConfClient *gconf_client;
+  gchar *server_name;
+
   SjMetadataMusicbrainz3Private *priv;
 
   priv = GET_PRIVATE (self);
 
-  priv->mb = mb_webservice_new();
+  priv->mb = mb_webservice_new ();
 
   gconf_client = gconf_client_get_default ();
 
+  server_name = gconf_client_get_string (gconf_client, GCONF_MUSICBRAINZ_SERVER, NULL);
+
+  if (server_name && strcmp (server_name, "") != 0) {
+    mb_webservice_set_host (priv->mb, server_name);
+  }
+
+  g_free (server_name);
+
   /* Set the HTTP proxy */
   if (gconf_client_get_bool (gconf_client, GCONF_PROXY_USE_PROXY, NULL)) {
     char *proxy_host;
